<?php

/**
 * @file
 * Command-line runner for migrations.
 */

/**
 * Implements hook_drush_command().
 */
function migrate_run_drush_command() {
  $items['migrate-status'] = [
    'description' => 'List all migrations with current status.',
    'options' => [
      'tag' => 'A comma-separated list of migration tags to list. If only --tag is provided, all migrations will be listed, grouped by tags.',
      'names-only' => 'Only return names, not all the details (faster)',
    ],
    'arguments' => [
      'migration' => 'Restrict to a comma-separated list of migrations. Optional',
    ],
    'examples' => [
      'migrate-status' => 'Retrieve status for all migrations',
      'migrate-status --tag' => 'Retrieve status for all migrations, grouped by tag',
      'migrate-status --tag=user,main_content' => 'Retrieve status for all migrations tagged with "user" or "main_content"',
      'migrate-status classification,article' => 'Retrieve status for specific migrations',
    ],
    'drupal dependencies' => ['migrate_run'],
    'aliases' => ['ms'],
  ];

  $items['migrate-import'] = [
    'description' => 'Perform one or more migration processes.',
    'options' => [
      'all' => 'Process all migrations.',
      'tag' => 'A comma-separated list of migration tags to import',
      'limit' => 'Limit on the number of items to process in each migration',
      'feedback' => 'Frequency of progress messages, in items processed',
      'idlist' => 'Comma-separated list of IDs to import',
      'update' => 'In addition to processing unprocessed items from the source, update previously-imported items with the current data',
      'force' => 'Force an operation to run, even if all dependencies are not satisfied',
      'execute-dependencies' => 'Execute all dependent migrations first.',
      'timestamp' => 'Show progress ending timestamp in progress messages.',
      'total' => 'Show total processed item number in progress messages.',
    ],
    'arguments' => [
      'migration' => 'ID of migration(s) to import. Delimit multiple using commas.',
    ],
    'examples' => [
      'migrate-import --all' => 'Perform all migrations',
      'migrate-import --tag=user,main_content' => 'Import all migrations tagged with user and main_content tags',
      'migrate-import classification,article' => 'Import new terms and nodes',
      'migrate-import beer_user --limit=2' => 'Import no more than 2 users',
      'migrate-import beer_user --idlist=5' => 'Import the user record with source ID 5',
      'migrate-import beer_user --limit=50 --feedback=20' => 'Import 50 users and show process message every 20th record'
    ],
    'drupal dependencies' => ['migrate_run'],
    'aliases' => ['mi'],
  ];

  $items['migrate-rollback'] = [
    'description' => 'Rollback one or more migrations.',
    'options' => [
      'all' => 'Process all migrations.',
      'tag' => 'A comma-separated list of migration tags to rollback',
      'feedback' => 'Frequency of progress messages, in items processed',
    ],
    'arguments' => [
      'migration' => 'Name of migration(s) to rollback. Delimit multiple using commas.',
    ],
    'examples' => [
      'migrate-rollback --all' => 'Perform all migrations',
      'migrate-rollback --tag=user,main_content' => 'Rollback all migrations tagged with user and main_content tags',
      'migrate-rollback classification,article' => 'Rollback imported terms and nodes',
    ],
    'drupal dependencies' => ['migrate_run'],
    'aliases' => ['mr'],
  ];

  $items['migrate-stop'] = [
    'description' => 'Stop an active migration operation.',
    'arguments' => [
      'migration' => 'ID of migration to stop',
    ],
    'drupal dependencies' => ['migrate_run'],
    'aliases' => ['mst'],
  ];

  $items['migrate-reset-status'] = [
    'description' => "Reset a active migration's status to idle.",
    'arguments' => [
      'migration' => 'ID of migration to reset',
    ],
    'drupal dependencies' => ['migrate_run'],
    'aliases' => ['mrs'],
  ];

  $items['migrate-messages'] = [
    'description' => 'View any messages associated with a migration.',
    'arguments' => [
      'migration' => 'ID of the migration',
    ],
    'options' => [
      'csv' => 'Export messages as a CSV'
    ],
    'examples' => [
      'migrate-messages article' => 'Show all messages for the article migration',
    ],
    'drupal dependencies' => ['migrate_run'],
    'aliases' => ['mmsg'],
  ];

  $items['migrate-fields-source'] = [
    'description' => 'List the fields available for mapping in a source.',
    'arguments' => [
      'migration' => 'ID of the migration',
    ],
    'examples' => [
      'migrate-fields-source article' => 'List fields for the source in the article migration',
    ],
    'drupal dependencies' => ['migrate_run'],
    'aliases' => ['mfs'],
  ];

  return $items;
}

/**
 * @param string $migration_ids
 *   Comma-separated list of migration IDs.
 *
 * @deprecated Use \Drupal::service('migrate_run.commands')->status() instead.
 */
function drush_migrate_run_migrate_status($migration_ids = '') {
  \Drupal::service('migrate_run.commands')->status($migration_ids, [
    'tag' => drush_get_option('tag'),
    'names-only' => drush_get_option('names-only'),
  ]);
}

/**
 * @param string $migration_ids
 *   Comma-separated list of migration IDs.
 *
 * @deprecated Use \Drupal::service('migrate_run.commands')->import() instead.
 */
function drush_migrate_run_migrate_import($migration_ids = '') {
  \Drupal::service('migrate_run.commands')->import($migration_ids, [
    'all' => drush_get_option('all'),
    'tag' => drush_get_option('tag'),
    'limit' => drush_get_option('limit'),
    'feedback' => drush_get_option('feedback'),
    'idlist' => drush_get_option('idlist'),
    'update' => drush_get_option('update'),
    'force' => drush_get_option('tag'),
    'execute-dependencies' => drush_get_option('xecute-dependencies'),
    'timestamp' => drush_get_option('timestamp'),
    'total' => drush_get_option('total'),
  ]);
}

/**
 * @param string $migration_ids
 *
 * @deprecated Use \Drupal::service('migrate_run.commands')->rollback() instead.
 */
function drush_migrate_run_migrate_rollback($migration_ids = '') {
  \Drupal::service('migrate_run.commands')->rollback($migration_ids, [
    'all' => drush_get_option('all'),
    'tag' => drush_get_option('tag'),
    'feedback' => drush_get_option('feedback'),
  ]);
}

/**
 * @param string $migration_id
 *
 * @deprecated Use \Drupal::service('migrate_run.commands')->stop() instead.
 */
function drush_migrate_run_migrate_stop($migration_id = '') {
  \Drupal::service('migrate_run.commands')->rollback($migration_id);
}

/**
 * @param string $migration_id
 *
 * @deprecated Use \Drupal::service('migrate_run.commands')->resetStatus()
 *   instead.
 */
function drush_migrate_run_migrate_reset_status($migration_id) {
  \Drupal::service('migrate_run.commands')->resetStatus($migration_id);
}

/**
 * @param string $migration_id
 *
 * @deprecated Use \Drupal::service('migrate_run.commands')->messages() instead.
 */
function drush_migrate_run_migrate_messages($migration_id) {
  \Drupal::service('migrate_run.commands')->messages($migration_id, ['csv' => NULL]);
}

/**
 * @param string $migration_id
 *
 * @deprecated Use \Drupal::service('migrate_run.commands')->fieldsSource()
 *   instead.
 */
function drush_migrate_run_migrate_fields_source($migration_id) {
  \Drupal::service('migrate_run.commands')->fieldsSource($migration_id);
}
